@@ -5,8 +5,12 @@
 */
 
 #include "alternativesmodel.h"
+
+#if HAVE_QTDBUS
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
+#endif
+
 #include <QDebug>
 #include <QDirIterator>
 #include <QIcon>
@@ -23,7 +27,7 @@
 
 #include "configuration.h"
 #include "helper.h"
-#include "job.h"
+#include "purpose_external_process_debug.h"
 
 using namespace Purpose;
 
@@ -41,14 +45,16 @@ static bool mimeTypeMatch(const QString &constraint, const QJsonValue &value)
     if (value.isArray()) {
         const auto array = value.toArray();
         for (const QJsonValue &val : array) {
-            if (mimeTypeMatch(constraint, val))
+            if (mimeTypeMatch(constraint, val)) {
                 return true;
+            }
         }
         return false;
     } else if (value.isObject()) {
         for (const QJsonValue &val : value.toObject()) {
-            if (mimeTypeMatch(constraint, val))
+            if (mimeTypeMatch(constraint, val)) {
                 return true;
+            }
         }
         return false;
     } else if (constraint.contains(QLatin1Char('*'))) {
@@ -64,7 +70,12 @@ static bool mimeTypeMatch(const QString &constraint, const QJsonValue &value)
 static bool dbusMatch(const QString &constraint, const QJsonValue &value)
 {
     Q_UNUSED(value)
+#if HAVE_QTDBUS
     return QDBusConnection::sessionBus().interface()->isServiceRegistered(constraint);
+#else
+    Q_UNUSED(constraint)
+    return false;
+#endif
 }
 
 static bool executablePresent(const QString &constraint, const QJsonValue &value)
@@ -100,20 +111,22 @@ public:
     {
         const QJsonObject obj = meta.rawData();
         if (!obj.value(QLatin1String("X-Purpose-PluginTypes")).toArray().contains(m_pluginType)) {
-            // qDebug() << "discarding" << meta.name() << KPluginMetaData::readStringList(meta.rawData(), QStringLiteral("X-Purpose-PluginTypes"));
+            // qCDebug(PURPOSE_EXTERNAL_PROCESS_LOG) << "discarding" << meta.name() << KPluginMetaData::readStringList(meta.rawData(),
+            // QStringLiteral("X-Purpose-PluginTypes"));
             return false;
         }
 
         if (disabledPlugins.contains(meta.pluginId()) || m_disabledPlugins.contains(meta.pluginId())) {
-            // qDebug() << "disabled plugin" << meta.name() << meta.pluginId();
+            // qCDebug(PURPOSE_EXTERNAL_PROCESS_LOG) << "disabled plugin" << meta.name() << meta.pluginId();
             return false;
         }
 
         // All constraints must match
         const QJsonArray constraints = obj.value(QLatin1String("X-Purpose-Constraints")).toArray();
         for (const QJsonValue &constraint : constraints) {
-            if (!constraintMatches(meta, constraint))
+            if (!constraintMatches(meta, constraint)) {
                 return false;
+            }
         }
         return true;
     }
@@ -133,14 +146,14 @@ public:
         Q_ASSERT(constraintRx.isValid());
         QRegularExpressionMatch match = constraintRx.match(constraint.toString());
         if (!match.isValid() || !match.hasMatch()) {
-            qWarning() << "wrong constraint" << constraint.toString();
+            qCWarning(PURPOSE_EXTERNAL_PROCESS_LOG) << "wrong constraint" << constraint.toString();
             return false;
         }
         const QString propertyName = match.captured(1);
         const QString constrainedValue = match.captured(2);
         const bool acceptable = s_matchFunctions.value(propertyName, defaultMatch)(constrainedValue, m_inputData.value(propertyName));
         if (!acceptable) {
-            //             qDebug() << "not accepted" << meta.name() << propertyName << constrainedValue << m_inputData[propertyName];
+            // qCDebug(PURPOSE_EXTERNAL_PROCESS_LOG) << "not accepted" << meta.name() << propertyName << constrainedValue << m_inputData[propertyName];
         }
         return acceptable;
     }
@@ -170,8 +183,9 @@ QHash<int, QByteArray> AlternativesModel::roleNames() const
 void AlternativesModel::setInputData(const QJsonObject &input)
 {
     Q_D(AlternativesModel);
-    if (input == d->m_inputData)
+    if (input == d->m_inputData) {
         return;
+    }
 
     d->m_inputData = input;
     initializeModel();
@@ -182,8 +196,9 @@ void AlternativesModel::setInputData(const QJsonObject &input)
 void AlternativesModel::setPluginType(const QString &pluginType)
 {
     Q_D(AlternativesModel);
-    if (pluginType == d->m_pluginType)
+    if (pluginType == d->m_pluginType) {
         return;
+    }
 
     d->m_pluginTypeData = Purpose::readPluginType(pluginType);
     d->m_pluginType = pluginType;
@@ -203,8 +218,9 @@ QStringList AlternativesModel::disabledPlugins() const
 void AlternativesModel::setDisabledPlugins(const QStringList &pluginIds)
 {
     Q_D(AlternativesModel);
-    if (pluginIds == d->m_disabledPlugins)
+    if (pluginIds == d->m_disabledPlugins) {
         return;
+    }
 
     d->m_disabledPlugins = pluginIds;
 
@@ -241,14 +257,15 @@ int AlternativesModel::rowCount(const QModelIndex &parent) const
 QVariant AlternativesModel::data(const QModelIndex &index, int role) const
 {
     Q_D(const AlternativesModel);
-    if (!index.isValid() || index.row() > d->m_plugins.count())
+    if (!index.isValid() || index.row() > d->m_plugins.count()) {
         return QVariant();
+    }
 
     KPluginMetaData data = d->m_plugins[index.row()];
     switch (role) {
     case Qt::DisplayRole:
         return data.name();
-    case Qt::ToolTip:
+    case Qt::ToolTipRole:
         return data.description();
     case IconNameRole:
         return data.iconName();
@@ -274,11 +291,12 @@ static QList<KPluginMetaData> findScriptedPackages(std::function<bool(const KPlu
     for (const QString &dir : dirs) {
         QDirIterator dirIt(dir, QDir::Dirs | QDir::NoDotAndDotDot);
 
-        for (; dirIt.hasNext();) {
+        while (dirIt.hasNext()) {
             QDir dir(dirIt.next());
             Q_ASSERT(dir.exists());
-            if (!dir.exists(QStringLiteral("metadata.json")))
+            if (!dir.exists(QStringLiteral("metadata.json"))) {
                 continue;
+            }
 
             const KPluginMetaData info = Purpose::createMetaData(dir.absoluteFilePath(QStringLiteral("metadata.json")));
             if (!addedPlugins.contains(info.pluginId()) && filter(info)) {
@@ -300,8 +318,10 @@ void AlternativesModel::initializeModel()
 
     const QJsonArray inbound = d->m_pluginTypeData.value(QLatin1String("X-Purpose-InboundArguments")).toArray();
     for (const QJsonValue &arg : inbound) {
-        if (!d->m_inputData.contains(arg.toString())) {
-            qWarning().nospace() << "Cannot initialize model with data " << d->m_inputData << ". missing: " << arg;
+        const auto key = arg.toString();
+        if (!d->m_inputData.contains(key)) {
+            qCWarning(PURPOSE_EXTERNAL_PROCESS_LOG).nospace()
+                << "Cannot initialize model for plugin type " << d->m_pluginType << " with data " << d->m_inputData << ": missing key " << key;
             return;
         }
     }
